Documentation
¶
Index ¶
Constants ¶
const LibraryName = "libpgmicro_sdk_kit"
Variables ¶
This section is empty.
Functions ¶
func LoadPgmicroLibrary ¶
func LoadPgmicroLibrary(config LoadPgmicroLibraryConfig) (handle uintptr, err error)
loads the library either from embedded artifacts or searching through LD_LIBRARY_PATH list
Types ¶
type LibraryLoadStrategy ¶
type LibraryLoadStrategy string
const ( EmbeddedLibraryLoadStrategy LibraryLoadStrategy = "embedded" SystemLibraryLoadStrategy LibraryLoadStrategy = "system" MixedLibraryLoadStrategy LibraryLoadStrategy = "mixed" )
type LoadPgmicroLibraryConfig ¶
type LoadPgmicroLibraryConfig struct {
// LoadStrategy available options
// "embedded" or "" (default): always load library from embedded resources
// "system": always load library from system pathes
// "mixed": try to load library from the embedded resources and fallback to system search if no library was found
LoadStrategy LibraryLoadStrategy
}
Click to show internal directories.
Click to hide internal directories.